@@ -24,6 +24,12 @@ import warnings
 
 
 class Agent(BaseAgent):
+    """
+    .. deprecated:: 0.7.0
+        Use :class:`BaseAgent` instead.
+
+    This class has been renamed for better uniformity in the grid2op framework.
+    """
     def __init__(self, *args, **kwargs):
         BaseAgent.__init__(self, *args, **kwargs)
         warnings.warn("Agent class has been renamed \"BaseAgent\". The Agent class will be removed"
