@@ -11,6 +11,7 @@ import numpy as np
 import copy
 from abc import ABC, abstractmethod
 
+from grid2op.dtypes import dt_int, dt_float, dt_bool
 from grid2op.Space import GridObjects
 from grid2op.Exceptions import *
 from grid2op.Parameters import Parameters
@@ -65,7 +66,7 @@ class BaseEnv(GridObjects, ABC):
     time_next_maintenance
     duration_next_maintenance
     hard_overflow_threshold
-    time_remaining_before_reconnection
+    time_remaining_before_line_reconnection
 
     # redispacthing
     target_dispatch
@@ -96,21 +97,21 @@ class BaseEnv(GridObjects, ABC):
         self.parameters = parameters
 
         # some timers
-        self._time_apply_act = 0
-        self._time_powerflow = 0
-        self._time_extract_obs = 0
-        self._time_opponent = 0
+        self._time_apply_act = dt_float(0)
+        self._time_powerflow = dt_float(0)
+        self._time_extract_obs = dt_float(0)
+        self._time_opponent = dt_float(0)
 
         # data relative to interpolation
-        self._epsilon_poly = epsilon_poly
-        self._tol_poly = tol_poly
+        self._epsilon_poly = dt_float(epsilon_poly)
+        self._tol_poly = dt_float(tol_poly)
 
         # define logger
         self.logger = None
 
         # and calendar data
         self.time_stamp = None
-        self.nb_time_step = 0
+        self.nb_time_step = dt_int(0)
 
         # observation
         self.current_obs = None
@@ -157,7 +158,7 @@ class BaseEnv(GridObjects, ABC):
         # maintenance / hazards
         self.time_next_maintenance = None
         self.duration_next_maintenance = None
-        self.time_remaining_before_reconnection = None
+        self.time_remaining_before_line_reconnection = None
 
         # store environment modifications
         self._injection = None
@@ -221,7 +222,7 @@ class BaseEnv(GridObjects, ABC):
         if not issubclass(self.opponent_action_class, BaseAction):
             raise EnvError("Impossible to make an environment with an opponent action class not derived from BaseAction")
         try:
-            self.opponent_init_budget = float(self.opponent_init_budget)
+            self.opponent_init_budget = dt_float(self.opponent_init_budget)
         except Exception as e:
             raise EnvError("Impossible to convert \"opponent_init_budget\" to a float with error {}".format(e))
         if self.opponent_init_budget < 0.:
@@ -247,36 +248,37 @@ class BaseEnv(GridObjects, ABC):
         # type of power flow to play
         # if True, then it will not disconnect lines above their thermal limits
         self.no_overflow_disconnection = self.parameters.NO_OVERFLOW_DISCONNECTION
-        self.timestep_overflow = np.zeros(shape=(self.n_line,), dtype=np.int)
+        self.timestep_overflow = np.zeros(shape=(self.n_line,), dtype=dt_int)
         self.nb_timestep_overflow_allowed = np.full(shape=(self.n_line,),
-                                                    fill_value=self.parameters.NB_TIMESTEP_POWERFLOW_ALLOWED)
+                                                    fill_value=self.parameters.NB_TIMESTEP_POWERFLOW_ALLOWED,
+                                                    dtype=dt_int)
         # store actions "cooldown"
-        self.times_before_line_status_actionable = np.zeros(shape=(self.n_line,), dtype=np.int)
+        self.times_before_line_status_actionable = np.zeros(shape=(self.n_line,), dtype=dt_int)
         self.max_timestep_line_status_deactivated = self.parameters.NB_TIMESTEP_LINE_STATUS_REMODIF
 
-        self.times_before_topology_actionable = np.zeros(shape=(self.n_sub,), dtype=np.int)
+        self.times_before_topology_actionable = np.zeros(shape=(self.n_sub,), dtype=dt_int)
         self.max_timestep_topology_deactivated = self.parameters.NB_TIMESTEP_TOPOLOGY_REMODIF
 
         # for maintenance operation
-        self.time_next_maintenance = np.zeros(shape=(self.n_line,), dtype=np.int) - 1
-        self.duration_next_maintenance = np.zeros(shape=(self.n_line,), dtype=np.int)
+        self.time_next_maintenance = np.zeros(shape=(self.n_line,), dtype=dt_int) - 1
+        self.duration_next_maintenance = np.zeros(shape=(self.n_line,), dtype=dt_int)
 
         # hazard (not used outside of this class, information is given in `time_remaining_before_line_reconnection`
-        self._hazard_duration = np.zeros(shape=(self.n_line,), dtype=np.int)
+        self._hazard_duration = np.zeros(shape=(self.n_line,), dtype=dt_int)
 
         # hard overflow part
         self.hard_overflow_threshold = self.parameters.HARD_OVERFLOW_THRESHOLD
-        self.time_remaining_before_line_reconnection = np.full(shape=(self.n_line,), fill_value=0, dtype=np.int)
+        self.time_remaining_before_line_reconnection = np.full(shape=(self.n_line,), fill_value=0, dtype=dt_int)
         self.env_dc = self.parameters.ENV_DC
 
         # Remember lines last bus
-        self.last_bus_line_or = np.full(shape=self.n_line, fill_value=1, dtype=np.int)
-        self.last_bus_line_ex = np.full(shape=self.n_line, fill_value=1, dtype=np.int)
+        self.last_bus_line_or = np.full(shape=self.n_line, fill_value=1, dtype=dt_int)
+        self.last_bus_line_ex = np.full(shape=self.n_line, fill_value=1, dtype=dt_int)
 
         # initialize maintenance / hazards
-        self.time_next_maintenance = np.zeros(shape=(self.n_line,), dtype=np.int) - 1
-        self.duration_next_maintenance = np.zeros(shape=(self.n_line,), dtype=np.int)
-        self.time_remaining_before_reconnection = np.full(shape=(self.n_line,), fill_value=0, dtype=np.int)
+        self.time_next_maintenance = np.zeros(shape=(self.n_line,), dtype=dt_int) - 1
+        self.duration_next_maintenance = np.zeros(shape=(self.n_line,), dtype=dt_int)
+        self.times_before_line_status_actionable = np.full(shape=(self.n_line,), fill_value=0, dtype=dt_int)
 
         self._reset_redispatching()
         self.__is_init = True
@@ -300,7 +302,7 @@ class BaseEnv(GridObjects, ABC):
         if not self.__is_init:
             raise Grid2OpException("Impossible to set the thermal limit to a non initialized Environment")
         try:
-            tmp = np.array(thermal_limit).flatten().astype(np.float)
+            tmp = np.array(thermal_limit).flatten().astype(dt_float)
         except Exception as e:
             raise Grid2OpException("Impossible to convert the vector as input into a 1d numpy float array.")
         if tmp.shape[0] != self.n_line:
@@ -314,18 +316,18 @@ class BaseEnv(GridObjects, ABC):
 
     def _reset_redispatching(self):
         # redispatching
-        self.target_dispatch = np.full(shape=self.n_gen, dtype=np.float, fill_value=0.)
-        self.actual_dispatch = np.full(shape=self.n_gen, dtype=np.float, fill_value=0.)
-        self.gen_uptime = np.full(shape=self.n_gen, dtype=np.int, fill_value=0)
-        self.gen_downtime = np.full(shape=self.n_gen, dtype=np.int, fill_value=0)
-        self.gen_activeprod_t = np.zeros(self.n_gen, dtype=np.float)
-        self.gen_activeprod_t_redisp = np.zeros(self.n_gen, dtype=np.float)
+        self.target_dispatch = np.full(shape=self.n_gen, dtype=dt_float, fill_value=0.)
+        self.actual_dispatch = np.full(shape=self.n_gen, dtype=dt_float, fill_value=0.)
+        self.gen_uptime = np.full(shape=self.n_gen, dtype=dt_int, fill_value=0)
+        self.gen_downtime = np.full(shape=self.n_gen, dtype=dt_int, fill_value=0)
+        self.gen_activeprod_t = np.zeros(self.n_gen, dtype=dt_float)
+        self.gen_activeprod_t_redisp = np.zeros(self.n_gen, dtype=dt_float)
         # if self.redispatching_unit_commitment_availble:
         #     # pretend that all generator has been turned off for a suffcient number of timestep,
         #     # otherwise when reconnecting them at first step it's complicated
         #     self.gen_downtime = self.gen_min_downtime
         # else:
-        #     self.gen_downtime = np.full(shape=self.n_gen, dtype=np.int, fill_value=0)
+        #     self.gen_downtime = np.full(shape=self.n_gen, dtype=dt_int, fill_value=0)
 
     @staticmethod
     def _get_poly(t, tmp_p, pmin, pmax):
@@ -945,7 +947,7 @@ class BaseEnv(GridObjects, ABC):
                 beg_ = time.time()
                 self.backend.update_thermal_limit(self)  # update the thermal limit, for DLR for example
                 overflow_lines = self.backend.get_line_overflow()
-                # overflow_lines = np.full(self.n_line, fill_value=False, dtype=np.bool)
+                # overflow_lines = np.full(self.n_line, fill_value=False, dtype=dt_bool)
 
                 # one timestep passed, i can maybe reconnect some lines
                 self.time_remaining_before_line_reconnection[self.time_remaining_before_line_reconnection > 0] -= 1
@@ -962,11 +964,9 @@ class BaseEnv(GridObjects, ABC):
                 # build the topological action "cooldown"
                 aff_lines, aff_subs = action.get_topological_impact()
                 if self.max_timestep_line_status_deactivated > 0:
-                    # this is a feature I want to consider in the parameters
                     self.times_before_line_status_actionable[self.times_before_line_status_actionable > 0] -= 1
                     self.times_before_line_status_actionable[aff_lines] = self.max_timestep_line_status_deactivated
                 if self.max_timestep_topology_deactivated > 0:
-                    # this is a feature I want to consider in the parameters
                     self.times_before_topology_actionable[self.times_before_topology_actionable > 0] -= 1
                     self.times_before_topology_actionable[aff_subs] = self.max_timestep_topology_deactivated
 
@@ -1061,20 +1061,21 @@ class BaseEnv(GridObjects, ABC):
 
         """
         self.no_overflow_disconnection = self.parameters.NO_OVERFLOW_DISCONNECTION
-        self.timestep_overflow = np.zeros(shape=(self.n_line,), dtype=np.int)
+        self.timestep_overflow = np.zeros(shape=(self.n_line,), dtype=dt_int)
         self.nb_timestep_overflow_allowed = np.full(shape=(self.n_line,),
-                                                    fill_value=self.parameters.NB_TIMESTEP_POWERFLOW_ALLOWED)
+                                                    fill_value=self.parameters.NB_TIMESTEP_POWERFLOW_ALLOWED,
+                                                    dtype=dt_int)
         self.nb_time_step = 0
         self.hard_overflow_threshold = self.parameters.HARD_OVERFLOW_THRESHOLD
         self.env_dc = self.parameters.ENV_DC
 
-        self.times_before_line_status_actionable = np.zeros(shape=(self.n_line,), dtype=np.int)
+        self.times_before_line_status_actionable = np.zeros(shape=(self.n_line,), dtype=dt_int)
         self.max_timestep_line_status_deactivated = self.parameters.NB_TIMESTEP_LINE_STATUS_REMODIF
 
-        self.times_before_topology_actionable = np.zeros(shape=(self.n_sub,), dtype=np.int)
+        self.times_before_topology_actionable = np.zeros(shape=(self.n_sub,), dtype=dt_int)
         self.max_timestep_topology_deactivated = self.parameters.NB_TIMESTEP_TOPOLOGY_REMODIF
 
-        self.time_remaining_before_line_reconnection = np.zeros(shape=(self.n_line,), dtype=np.int)
+        self.time_remaining_before_line_reconnection = np.zeros(shape=(self.n_line,), dtype=dt_int)
 
         # reset timings
         self._time_apply_act = 0
@@ -1087,9 +1088,9 @@ class BaseEnv(GridObjects, ABC):
         self.done = False
 
     def _reset_maintenance(self):
-        self.time_next_maintenance = np.zeros(shape=(self.n_line,), dtype=np.int) - 1
-        self.duration_next_maintenance = np.zeros(shape=(self.n_line,), dtype=np.int)
-        self.time_remaining_before_reconnection = np.full(shape=(self.n_line,), fill_value=0, dtype=np.int)
+        self.time_next_maintenance = np.zeros(shape=(self.n_line,), dtype=dt_int) - 1
+        self.duration_next_maintenance = np.zeros(shape=(self.n_line,), dtype=dt_int)
+        self.time_remaining_before_line_reconnection = np.full(shape=(self.n_line,), fill_value=0, dtype=dt_int)
 
     def __enter__(self):
         """
@@ -1157,8 +1158,8 @@ class BaseEnv(GridObjects, ABC):
                 tmp = grid_layout[el]
                 try:
                     x,y = tmp
-                    x = float(x)
-                    y = float(y)
+                    x = dt_float(x)
+                    y = dt_float(y)
                     res[el] = (x, y)
                 except Exception as e_:
                     raise EnvError("attach_layout: impossible to convert the value of \"{}\" to a pair of float "
@@ -1175,3 +1176,21 @@ class BaseEnv(GridObjects, ABC):
                 self.voltage_controler.attach_layout(res)
             if self.opponent_action_space is not None:
                 self.opponent_action_space.attach_layout(res)
+
+    def fast_forward_chronics(self, nb_timestep):
+        """
+        This method allows you to skip some time step at the beginning of the chronics.
+
+        This is usefull at the beginning of the training, if you want your agent to learn on more diverse scenarios.
+        Indeed, the data provided in the chronics usually starts always at the same date time (for example Jan 1st at
+        00:00). This can lead to suboptimal exploration, as during this phase, only a few time steps are managed by
+        the agent, so in general these few time steps will correspond to grid state around Jan 1st at 00:00.
+
+
+        Parameters
+        ----------
+        nb_timestep: ``int``
+            Number of time step to "fast forward"
+
+        """
+        self.chronics_handler.fast_forward_chronics(nb_timestep)
\ No newline at end of file
