@@ -1,9 +1,13 @@
 __all__ = [
-    "CompleteObservation",
+    # private
     "_ObsEnv",
+    # real export
+    "CompleteObservation",
     "BaseObservation",
+    "ObservationSpace",
+    # deprecated
+    "Observation",
     "ObservationHelper",
-    "Observation"
 ]
 
 
@@ -28,4 +32,4 @@ class Observation(BaseObservation):
         BaseObservation.__init__(self, *args, **kwargs)
         warnings.warn("Observation class has been renamed \"BaseObservation\". The Observation class will be removed"
                       "in future versions.",
-                      category=PendingDeprecationWarning)
\ No newline at end of file
+                      category=PendingDeprecationWarning)
