@@ -1,7 +1,16 @@
+# Copyright (c) 2019-2020, RTE (https://www.rte-france.com)
+# See AUTHORS.txt
+# This Source Code Form is subject to the terms of the Mozilla Public License, version 2.0.
+# If a copy of the Mozilla Public License, version 2.0 was not distributed with this file,
+# you can obtain one at http://mozilla.org/MPL/2.0/.
+# SPDX-License-Identifier: MPL-2.0
+# This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
+
 import numpy as np
 
 from grid2op.Reward.BaseReward import BaseReward
 
+
 class DistanceReward(BaseReward):
     """
     This reward computes a penalty based on the distance of the current grid to the grid at time 0.
@@ -11,7 +20,8 @@ class DistanceReward(BaseReward):
         self.reward_min = 0.0
         self.reward_max = 1.0
 
-    def __call__(self, action, env, has_error, is_done, is_illegal, is_ambiguous):
+    def __call__(self, action, env, has_error,
+                 is_done, is_illegal, is_ambiguous):
         # Get topo from env
         obs = env.current_obs
         topo = obs.topo_vect
@@ -31,7 +41,7 @@ class DistanceReward(BaseReward):
             # Set index to next sub station
             idx += n_elems_on_sub
 
-
-        r = np.interp(diff, [0.0, len(topo) * 1.0], [self.reward_min, self.reward_max])
-        r = self.reward_max - r
+        r = np.interp(diff,
+                      [0.0, len(topo) * 1.0],
+                      [self.reward_max, self.reward_min])
         return r
