@@ -90,6 +90,8 @@ class RewardHelper:
         """
         if not is_done and not has_error:
             res = self.template_reward(action, env, has_error, is_done, is_illegal, is_ambiguous)
+        elif is_done and not has_error:
+            res = self.template_reward.reward_max
         else:
             # no more data to consider, no powerflow has been run, reward is what it is
             res = self.template_reward.reward_min
