@@ -8,6 +8,7 @@
 
 import numpy as np
 
+from grid2op.dtypes import dt_float
 _case_14_layout = [(-280, -81), (-100, -270), (366, -270), (366, -54),
                    (-64, -54), (-64, 54), (450, 0), (550, 0), (326, 54),
                    (222, 108), (79, 162), (-170, 270), (-64, 270), (222, 216)]
@@ -19,21 +20,21 @@ case14_test_TH_LIM = np.array([352.8251645,    352.8251645 , 183197.68156979, 18
                                183197.68156979,  12213.17877132, 183197.68156979,    352.8251645,
                                352.8251645 ,    352.8251645 ,    352.8251645 ,    352.8251645,
                                183197.68156979, 183197.68156979, 183197.68156979,    352.8251645,
-                               352.8251645 ,    352.8251645 ,   2721.79412618,   2721.79412618])
+                               352.8251645 ,    352.8251645 ,   2721.79412618,   2721.79412618]).astype(dt_float)
 
 case14_redisp_layout = _case_14_layout
 case14_redisp_TH_LIM = np.array([3.84900179e+02, 3.84900179e+02, 2.28997102e+05, 2.28997102e+05,
                                  2.28997102e+05, 1.52664735e+04, 2.28997102e+05, 3.84900179e+02,
                                  3.84900179e+02, 1.83285800e+02, 3.84900179e+02, 3.84900179e+02,
                                  2.28997102e+05, 2.28997102e+05, 6.93930612e+04, 3.84900179e+02,
-                                 3.84900179e+02, 2.40562612e+02, 3.40224266e+03, 3.40224266e+03])
+                                 3.84900179e+02, 2.40562612e+02, 3.40224266e+03, 3.40224266e+03]).astype(dt_float)
 
 case14_real_layout = _case_14_layout
 case14_real_TH_LIM = np.array([384.900179, 384.900179, 380.0, 380.0,
                                157.0, 380.0, 380.0, 1077.7205012,
                                461.8802148,  769.80036, 269.4301253, 384.900179,
                                760.0, 380.0, 760.0, 384.900179,
-                               230.9401074, 170.79945452, 3402.24266, 3402.24266])
+                               230.9401074, 170.79945452, 3402.24266, 3402.24266]).astype(dt_float)
 
 
 
