@@ -6,23 +6,20 @@
 # SPDX-License-Identifier: MPL-2.0
 # This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
 
-import os
-import sys
 import copy
-import unittest
 import json
-import numpy as np
-import pdb
 import re
 from abc import ABC, abstractmethod
 
 from grid2op.tests.helper_path_test import *
 
+from grid2op.dtypes import dt_int, dt_float, dt_bool
 from grid2op.Exceptions import *
 from grid2op.Action import *
 from grid2op.Rules import RulesChecker, DefaultRules
 from grid2op.Space import GridObjects
-from grid2op._utils import save_to_dict
+from grid2op.Space.space_utils import save_to_dict
+
 
 class TestActionBase(ABC):
 
@@ -47,7 +44,7 @@ class TestActionBase(ABC):
                                     name_load=["load_{}".format(i) for i in range(11)],
                                     name_line=["line_{}".format(i) for i in range(20)],
                                     name_sub=["sub_{}".format(i) for i in range(14)],
-                                    sub_info=np.array([3, 6, 4, 6, 5, 6, 3, 2, 5, 3, 3, 3, 4, 3], dtype=np.int),
+                                    sub_info=np.array([3, 6, 4, 6, 5, 6, 3, 2, 5, 3, 3, 3, 4, 3], dtype=dt_int),
                                     load_to_subid=np.array([1,  2,  3,  4,  5,  8,  9, 10, 11, 12, 13]),
                                     gen_to_subid=np.array([0, 1, 2, 5, 7]),
                                     line_or_to_subid=np.array([ 0,  0,  1,  1,  1,  2,  3,  3,  3,  4,  5,  5,
@@ -153,7 +150,7 @@ class TestActionBase(ABC):
         """
         self._skipMissingKey('injection')
 
-        new_vect = np.random.randn(self.helper_action.n_load)
+        new_vect = np.random.randn(self.helper_action.n_load).astype(dt_float)
         action = self.helper_action({"injection": {"load_p": new_vect}})
         self.compare_vect(action._dict_inj["load_p"], new_vect)
         for i in range(self.helper_action.n_load):
@@ -166,7 +163,7 @@ class TestActionBase(ABC):
         """
         self._skipMissingKey('injection')
 
-        new_vect = np.random.randn(self.helper_action.n_gen)
+        new_vect = np.random.randn(self.helper_action.n_gen).astype(dt_float)
         action = self.helper_action({"injection": {"prod_v": new_vect}})
         self.compare_vect(action._dict_inj["prod_v"], new_vect)
         for i in range(self.helper_action.n_gen):
@@ -179,8 +176,8 @@ class TestActionBase(ABC):
         """
         self._skipMissingKey('injection')
 
-        new_vect = np.random.randn(self.helper_action.n_load)
-        new_vect2 = np.random.randn(self.helper_action.n_load)
+        new_vect = np.random.randn(self.helper_action.n_load).astype(dt_float)
+        new_vect2 = np.random.randn(self.helper_action.n_load).astype(dt_float)
         action = self.helper_action({"injection": {"load_p": new_vect, "load_q": new_vect2}})
         assert self.compare_vect(action._dict_inj["load_p"], new_vect)
         assert self.compare_vect(action._dict_inj["load_q"], new_vect2)
@@ -196,7 +193,7 @@ class TestActionBase(ABC):
         self._skipMissingKey('set_line_status')
 
         for i in range(self.helper_action.n_line):
-            disco = np.full(shape=self.helper_action.n_line, fill_value=0, dtype=np.int)
+            disco = np.full(shape=self.helper_action.n_line, fill_value=0, dtype=dt_int)
             disco[i] = 1
             action = self.helper_action({"set_line_status": disco})
             for j in range(self.helper_action.n_line):
@@ -211,7 +208,7 @@ class TestActionBase(ABC):
         self._skipMissingKey('set_line_status')
 
         for i in range(self.helper_action.n_line):
-            disco = np.full(shape=self.helper_action.n_line, fill_value=0, dtype=np.int)
+            disco = np.full(shape=self.helper_action.n_line, fill_value=0, dtype=dt_int)
             disco[i] = -1
             action = self.helper_action({"set_line_status": disco})
             for j in range(self.helper_action.n_line):
@@ -226,7 +223,7 @@ class TestActionBase(ABC):
         self._skipMissingKey('hazards')
 
         for i in range(self.helper_action.n_line):
-            disco = np.full(shape=self.helper_action.n_line, fill_value=False, dtype=np.bool)
+            disco = np.full(shape=self.helper_action.n_line, fill_value=False, dtype=dt_bool)
             disco[i] = True
             action = self.helper_action({"hazards": disco})
             for j in range(self.helper_action.n_line):
@@ -239,7 +236,7 @@ class TestActionBase(ABC):
         self._skipMissingKey('change_line_status')
 
         for i in range(self.helper_action.n_line):
-            disco = np.full(shape=self.helper_action.n_line, fill_value=False, dtype=np.bool)
+            disco = np.full(shape=self.helper_action.n_line, fill_value=False, dtype=dt_bool)
             disco[i] = True
             action = self.helper_action({"change_line_status": disco})
             for j in range(self.helper_action.n_line):
@@ -259,7 +256,7 @@ class TestActionBase(ABC):
     def test_update_set_topo_by_dict_sub(self):
         self._skipMissingKey('set_bus')
 
-        arr = np.array([1, 1, 1, 2, 2, 2], dtype=np.int)
+        arr = np.array([1, 1, 1, 2, 2, 2], dtype=dt_int)
         action = self.helper_action({"set_bus": {"substations_id": [(1, arr)]}})
         assert action.effect_on(line_id=2)["set_bus_or"] == 1
         assert action.effect_on(line_id=3)["set_bus_or"] == 1
@@ -274,8 +271,8 @@ class TestActionBase(ABC):
     def test_update_set_topo_by_dict_sub2(self):
         self._skipMissingKey('set_bus')
 
-        arr = np.array([1, 1, 1, 2, 2, 2], dtype=np.int)
-        arr3 = np.array([1, 2, 1, 2, 1, 2], dtype=np.int)
+        arr = np.array([1, 1, 1, 2, 2, 2], dtype=dt_int)
+        arr3 = np.array([1, 2, 1, 2, 1, 2], dtype=dt_int)
         action = self.helper_action({"set_bus": {"substations_id": [(3, arr3), (1, arr)]}})
         assert action.effect_on(line_id=2)["set_bus_or"] == 1
         assert action.effect_on(line_id=3)["set_bus_or"] == 1
@@ -331,7 +328,7 @@ class TestActionBase(ABC):
     def test_update_change_bus_by_dict_sub(self):
         self._skipMissingKey('change_bus')
 
-        arr = np.array([True, True, True, False, False, False], dtype=np.bool)
+        arr = np.array([True, True, True, False, False, False], dtype=dt_bool)
         action = self.helper_action({"change_bus": {"substations_id": [(1, arr)]}})
         assert action.effect_on(line_id=2)["change_bus_or"] == True
         assert action.effect_on(line_id=3)["change_bus_or"] == True
@@ -346,8 +343,8 @@ class TestActionBase(ABC):
     def test_update_change_bus_by_dict_sub2(self):
         self._skipMissingKey('change_bus')
 
-        arr = np.array([True, True, True, False, False, False], dtype=np.bool)
-        arr3 = np.array([True, False, True, False, True, False], dtype=np.bool)
+        arr = np.array([True, True, True, False, False, False], dtype=dt_bool)
+        arr3 = np.array([True, False, True, False, True, False], dtype=dt_bool)
         action = self.helper_action({"change_bus": {"substations_id": [(3, arr3), (1, arr)]}})
         assert action.effect_on(line_id=2)["change_bus_or"] == True
         assert action.effect_on(line_id=3)["change_bus_or"] == True
@@ -407,7 +404,7 @@ class TestActionBase(ABC):
         self._skipMissingKey('set_bus')
         self._skipMissingKey('set_line_status')
 
-        arr = np.array([1, 1, 1, 2, 2, 2], dtype=np.int)
+        arr = np.array([1, 1, 1, 2, 2, 2], dtype=dt_int)
         id_ = 2
         action = self.helper_action({"set_bus": {"substations_id": [(1, arr)]}})
         arr2 = np.zeros(self.helper_action.n_line)
@@ -427,7 +424,7 @@ class TestActionBase(ABC):
         self._skipMissingKey('set_bus')
         self._skipMissingKey('hazards')
 
-        arr = np.array([1, 1, 1, 2, 2, 2], dtype=np.int)
+        arr = np.array([1, 1, 1, 2, 2, 2], dtype=dt_int)
         id_ = 2
         action = self.helper_action({"set_bus": {"substations_id": [(1, arr)]}})
         assert action.effect_on(line_id=id_)["set_bus_or"] == 1, "fail for {}".format(self.helper_action.actionClass)
@@ -440,8 +437,8 @@ class TestActionBase(ABC):
         self._skipMissingKey('set_bus')
         self._skipMissingKey('change_bus')
 
-        arr1 = np.array([False, False, False, True, True, True], dtype=np.bool)
-        arr2 = np.array([1, 1, 2, 2], dtype=np.int)
+        arr1 = np.array([False, False, False, True, True, True], dtype=dt_bool)
+        arr2 = np.array([1, 1, 2, 2], dtype=dt_int)
         id_1 = 1
         id_2 = 12
         action = self.helper_action({"change_bus": {"substations_id": [(id_1, arr1)]},
@@ -460,8 +457,8 @@ class TestActionBase(ABC):
         self._skipMissingKey('set_bus')
         self._skipMissingKey('change_bus')
 
-        arr1 = np.array([False, False, False, True, True, True], dtype=np.bool)
-        arr2 = np.array([1, 1, 2, 2], dtype=np.int)
+        arr1 = np.array([False, False, False, True, True, True], dtype=dt_bool)
+        arr2 = np.array([1, 1, 2, 2], dtype=dt_int)
         id_1 = 1
         id_2 = 12
         action = self.helper_action({"change_bus": {"substations_id": [(id_1, arr1)]},
@@ -501,8 +498,8 @@ class TestActionBase(ABC):
         self._skipMissingKey('set_bus')
         self._skipMissingKey('change_bus')
 
-        arr1 = np.array([False, False, False, True, True, True], dtype=np.bool)
-        arr2 = np.array([1, 1, 2, 2], dtype=np.int)
+        arr1 = np.array([False, False, False, True, True, True], dtype=dt_bool)
+        arr2 = np.array([1, 1, 2, 2], dtype=dt_int)
         id_1 = 1
         id_2 = 12
         action1 = self.helper_action({"change_bus": {"substations_id": [(id_1, arr1)]},
@@ -517,8 +514,8 @@ class TestActionBase(ABC):
         self._skipMissingKey('set_bus')
         self._skipMissingKey('change_bus')
 
-        arr1 = np.array([False, False, False, True, True, True], dtype=np.bool)
-        arr2 = np.array([1, 1, 2, 2], dtype=np.int)
+        arr1 = np.array([False, False, False, True, True, True], dtype=dt_bool)
+        arr2 = np.array([1, 1, 2, 2], dtype=dt_int)
         id_1 = 1
         id_2 = 12
         action1 = self.helper_action({"change_bus": {"substations_id": [(id_1, arr1)]},
@@ -542,18 +539,18 @@ class TestActionBase(ABC):
         self._skipMissingKey('change_line_status')
         self._skipMissingKey('injection')
 
-        arr1 = np.array([False, False, False, True, True, True], dtype=np.bool)
-        arr2 = np.array([1, 1, 2, 2], dtype=np.int)
+        arr1 = np.array([False, False, False, True, True, True], dtype=dt_bool)
+        arr2 = np.array([1, 1, 2, 2], dtype=dt_int)
         id_1 = 1
         id_2 = 12
-        new_vect = np.random.randn(self.helper_action.n_load)
-        new_vect2 = np.random.randn(self.helper_action.n_load)
+        new_vect = np.random.randn(self.helper_action.n_load).astype(dt_int)
+        new_vect2 = np.random.randn(self.helper_action.n_load).astype(dt_int)
 
-        change_status_orig = np.random.randint(0, 2, self.helper_action.n_line).astype(np.bool)
+        change_status_orig = np.random.randint(0, 2, self.helper_action.n_line).astype(dt_bool)
         set_status_orig = np.random.randint(-1, 2, self.helper_action.n_line)
         set_status_orig[change_status_orig] = 0
 
-        change_topo_vect_orig = np.random.randint(0, 2, self.helper_action.dim_topo).astype(np.bool)
+        change_topo_vect_orig = np.random.randint(0, 2, self.helper_action.dim_topo).astype(dt_bool)
         # powerline that are set to be reconnected, can't be moved to another bus
         change_topo_vect_orig[self.helper_action.line_or_pos_topo_vect[set_status_orig == 1]] = False
         change_topo_vect_orig[self.helper_action.line_ex_pos_topo_vect[set_status_orig == 1]] = False
@@ -597,11 +594,11 @@ class TestActionBase(ABC):
         id_line = 17
         id_line2 = 15
 
-        arr1 = np.array([False, False, False, True, True, True], dtype=np.bool)
-        arr2 = np.array([1, 1, 2, 2], dtype=np.int)
-        arr_line1 = np.full(self.helper_action.n_line, fill_value=False, dtype=np.bool)
+        arr1 = np.array([False, False, False, True, True, True], dtype=dt_bool)
+        arr2 = np.array([1, 1, 2, 2], dtype=dt_int)
+        arr_line1 = np.full(self.helper_action.n_line, fill_value=False, dtype=dt_bool)
         arr_line1[id_line] = True
-        arr_line2 = np.full(self.helper_action.n_line, fill_value=0, dtype=np.int)
+        arr_line2 = np.full(self.helper_action.n_line, fill_value=0, dtype=dt_int)
         arr_line2[id_line2] = 2
 
         do_nothing = self.helper_action({})
@@ -852,6 +849,7 @@ class TestPowerlineChangeAction(TestActionBase, unittest.TestCase):
     def _action_setup(self):
         return ActionSpace(self.gridobj, legal_action=self.game_rules.legal_action, actionClass=PowerlineChangeAction)
 
+
 class TestPowerlineSetAndDispatchAction(TestActionBase, unittest.TestCase):
     """
     Test suite using the PowerlineSetAction class
@@ -860,6 +858,7 @@ class TestPowerlineSetAndDispatchAction(TestActionBase, unittest.TestCase):
     def _action_setup(self):
         return ActionSpace(self.gridobj, legal_action=self.game_rules.legal_action, actionClass=PowerlineSetAndDispatchAction)
 
+
 class TestPowerlineChangeAndDispatchAction(TestActionBase, unittest.TestCase):
     """
     Test suite using the PowerlineChangeAction class
