@@ -6,19 +6,14 @@
 # SPDX-License-Identifier: MPL-2.0
 # This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
 
-import os
-import sys
-import unittest
-import datetime
 import time
 import warnings
-import numpy as np
 import pandapower as pp
 
 from grid2op.tests.helper_path_test import *
 
 from grid2op.Exceptions import *
-from grid2op.MakeEnv import make
+from grid2op.MakeEnv import make_new
 from grid2op.Agent import PowerLineSwitch, TopologyGreedy, DoNothingAgent
 from grid2op.Parameters import Parameters
 
@@ -40,7 +35,7 @@ class TestAgent(HelperTests):
         param.init_from_dict({"NO_OVERFLOW_DISCONNECTION": True})
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            self.env = make("case14_redisp", param=param)
+            self.env = make_new("rte_case14_redisp", test=True, param=param)
 
     def tearDown(self):
         self.env.close()
@@ -88,19 +83,19 @@ class TestAgent(HelperTests):
         agent = DoNothingAgent(self.env.helper_action_player)
         i, cum_reward = self._aux_test_agent(agent)
         assert i == 31, "The powerflow diverged before step 30 for do nothing"
-        assert np.abs(cum_reward - 35140.02895) <= self.tol_one, "The reward has not been properly computed"
+        assert np.abs(cum_reward - 35140.02903) <= self.tol_one, "The reward has not been properly computed"
 
     def test_1_powerlineswitch(self):
         agent = PowerLineSwitch(self.env.helper_action_player)
         i, cum_reward = self._aux_test_agent(agent)
         assert i == 31, "The powerflow diverged before step 30 for powerline switch agent"
-        assert np.abs(cum_reward - 35147.56202) <= self.tol_one, "The reward has not been properly computed"
+        assert np.abs(cum_reward - 35147.56210) <= self.tol_one, "The reward has not been properly computed"
 
     def test_2_busswitch(self):
         agent = TopologyGreedy(self.env.helper_action_player)
         i, cum_reward = self._aux_test_agent(agent, i_max=10)
         assert i == 11, "The powerflow diverged before step 10 for greedy agent"
-        assert np.abs(cum_reward - 12075.38800) <= self.tol_one, "The reward has not been properly computed"
+        assert np.abs(cum_reward - 12075.38803) <= self.tol_one, "The reward has not been properly computed"
 
 
 if __name__ == "__main__":
