@@ -6,22 +6,20 @@
 # SPDX-License-Identifier: MPL-2.0
 # This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
 
-import os
-import sys
-import unittest
-import numpy as np
 import pdb
 import warnings
 from grid2op.tests.helper_path_test import *
 from grid2op.Environment import MultiEnvironment
-from grid2op import make
+from grid2op.MakeEnv import make_new
 
 
 class TestLoadingMultiEnv(unittest.TestCase):
     def test_creation_multienv(self):
         nb_env = 1
-        with make("case5_example") as env:
-            multi_envs = MultiEnvironment(env=env, nb_env=nb_env)
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            with make_new("rte_case5_example", test=True) as env:
+                multi_envs = MultiEnvironment(env=env, nb_env=nb_env)
         multi_envs.close()
 
 
