@@ -7,7 +7,6 @@
 # This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.
 
 import os
-import sys
 import unittest
 import numpy as np
 import copy
@@ -19,16 +18,13 @@ from grid2op.tests.helper_path_test import HelperTests, PATH_DATA_TEST_PP
 from grid2op.Action import ActionSpace, CompleteAction
 from grid2op.Backend import PandaPowerBackend
 from grid2op.Parameters import Parameters
-from grid2op.Chronics import ChronicsHandler, ChangeNothing
+from grid2op.Chronics import ChronicsHandler
 from grid2op.Environment import Environment
 from grid2op.Exceptions import *
 from grid2op.Rules import RulesChecker
-from grid2op.MakeEnv import make
+from grid2op.MakeEnv import make_new
 from grid2op.Rules import AlwaysLegal
-from grid2op.Space import GridObjects
-
 PATH_DATA_TEST = PATH_DATA_TEST_PP
-import pandapower as pppp
 
 
 class TestLoadingCase(unittest.TestCase):
@@ -902,7 +898,7 @@ class TestChangeBusAffectRightBus(unittest.TestCase):
     def test_set_bus(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            env = make()
+            env = make_new(test=True)
         env.reset()
         # action = env.helper_action_player({"change_bus": {"lines_or_id": [17]}})
         action = env.helper_action_player({"set_bus": {"lines_or_id": [(17, 2)]}})
@@ -913,7 +909,7 @@ class TestChangeBusAffectRightBus(unittest.TestCase):
     def test_change_bus(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            env = make()
+            env = make_new(test=True)
         env.reset()
         action = env.helper_action_player({"change_bus": {"lines_or_id": [17]}})
         obs, reward, done, info = env.step(action)
@@ -923,7 +919,7 @@ class TestChangeBusAffectRightBus(unittest.TestCase):
     def test_change_bustwice(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            env = make()
+            env = make_new(test=True)
         env.reset()
         action = env.helper_action_player({"change_bus": {"lines_or_id": [17]}})
         obs, reward, done, info = env.step(action)
@@ -934,7 +930,7 @@ class TestChangeBusAffectRightBus(unittest.TestCase):
     def test_isolate_load(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            env = make()
+            env = make_new(test=True)
         act = env.action_space({"set_bus": {"loads_id": [(0, 2)]}})
         obs, reward, done, info = env.step(act)
         assert done, "an isolated laod has not lead to a game over"
@@ -942,7 +938,7 @@ class TestChangeBusAffectRightBus(unittest.TestCase):
     def test_reco_disco_bus(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            env_case1 = make("case5_example", gamerules_class=AlwaysLegal)
+            env_case1 = make_new("rte_case5_example", test=True, gamerules_class=AlwaysLegal)
         obs = env_case1.reset()  # reset is good
         act = env_case1.action_space.disconnect_powerline(line_id=5)  # I disconnect a powerline
         obs, reward, done, info = env_case1.step(act)  # do the action, it's valid
@@ -955,7 +951,7 @@ class TestChangeBusAffectRightBus(unittest.TestCase):
     def test_reco_disco_bus2(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            env_case2 = make("case5_example", gamerules_class=AlwaysLegal)
+            env_case2 = make_new("rte_case5_example", test=True, gamerules_class=AlwaysLegal)
         obs = env_case2.reset()  # reset is good
         obs, reward, done, info = env_case2.step(env_case2.action_space())  # do the action, it's valid
         act_case2 = env_case2.action_space.reconnect_powerline(line_id=5, bus_or=2, bus_ex=2)  # reconnect powerline on bus 2 both ends
@@ -968,7 +964,7 @@ class TestChangeBusAffectRightBus(unittest.TestCase):
     def test_reco_disco_bus3(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            env_case2 = make("case5_example", gamerules_class=AlwaysLegal)
+            env_case2 = make_new("rte_case5_example", test=True, gamerules_class=AlwaysLegal)
         obs = env_case2.reset()  # reset is good
         obs, reward, done, info = env_case2.step(env_case2.action_space())  # do the action, it's valid
         act_case2 = env_case2.action_space.reconnect_powerline(line_id=5, bus_or=1, bus_ex=2)  # reconnect powerline on bus 2 both ends
@@ -979,7 +975,7 @@ class TestChangeBusAffectRightBus(unittest.TestCase):
     def test_reco_disco_bus4(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            env_case2 = make("case5_example", gamerules_class=AlwaysLegal)
+            env_case2 = make_new("rte_case5_example", test=True, gamerules_class=AlwaysLegal)
         obs = env_case2.reset()  # reset is good
         obs, reward, done, info = env_case2.step(env_case2.action_space())  # do the action, it's valid
         act_case2 = env_case2.action_space.reconnect_powerline(line_id=5, bus_or=2, bus_ex=1)  # reconnect powerline on bus 2 both ends
@@ -990,7 +986,7 @@ class TestChangeBusAffectRightBus(unittest.TestCase):
     def test_reco_disco_bus5(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            env_case2 = make("case5_example", gamerules_class=AlwaysLegal)
+            env_case2 = make_new("rte_case5_example", test=True, gamerules_class=AlwaysLegal)
         obs = env_case2.reset()  # reset is good
         act_case2 = env_case2.action_space({"set_bus": {"lines_or_id": [(5,2)], "lines_ex_id": [(5,2)]}})  # reconnect powerline on bus 2 both ends
         # this should not lead to a game over this time, the grid is connex!
@@ -1002,15 +998,17 @@ class TestShuntAction(HelperTests):
     def test_shunt_ambiguous_id_incorrect(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            with make("case5_example", gamerules_class=AlwaysLegal, action_class=CompleteAction) as env_case2:
+            with make_new("rte_case5_example", test=True, gamerules_class=AlwaysLegal, action_class=CompleteAction) as env_case2:
                 with self.assertRaises(AmbiguousAction):
                     act = env_case2.action_space({"shunt": {"set_bus": [(0, 2)]}})
 
     def test_shunt_effect(self):
         with warnings.catch_warnings():
             warnings.filterwarnings("ignore")
-            env_ref = make("case14_realistic", gamerules_class=AlwaysLegal, action_class=CompleteAction)
-            env_change_q = make("case14_realistic", gamerules_class=AlwaysLegal, action_class=CompleteAction)
+            env_ref = make_new("rte_case14_realistic", test=True, gamerules_class=AlwaysLegal,
+                               action_class=CompleteAction)
+            env_change_q = make_new("rte_case14_realistic", test=True, gamerules_class=AlwaysLegal,
+                                    action_class=CompleteAction)
 
         obs_ref, *_ = env_ref.step(env_ref.action_space())
         obs_change_p, *_ = env_change_q.step(env_change_q.action_space({"shunt": {"shunt_q": [(0, -30)]}}))
@@ -1023,12 +1021,15 @@ class TestShuntAction(HelperTests):
         obs_ref, *_ = env_ref.step(env_ref.action_space())
         assert np.abs(obs_ref.v_or[10] - obs_change_p.v_or[10]) < self.tol_one
 
+
 class TestResetEqualsLoadGrid(unittest.TestCase):
     def setUp(self):
-        self.env1 = make("case5_example", backend=PandaPowerBackend())
-        self.backend1 = self.env1.backend
-        self.env2 = make("case5_example", backend=PandaPowerBackend())
-        self.backend2 = self.env2.backend
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore")
+            self.env1 = make_new("rte_case5_example", test=True, backend=PandaPowerBackend())
+            self.backend1 = self.env1.backend
+            self.env2 = make_new("rte_case5_example", test=True, backend=PandaPowerBackend())
+            self.backend2 = self.env2.backend
 
     def tearDown(self):
         self.env1.close()
